@@ -2,8 +2,11 @@ from io import BytesIO
 import base64
 import lzma
 import numpy as np
+import logging
 from PIL import Image, ImageDraw, ImageOps
 
+_LOGGER = logging.getLogger(__name__)
+
 class Map:
     def __init__(self):
         self.buffer = np.zeros((64, 100, 100))
@@ -12,6 +15,8 @@ class Map:
         self.base64Image = None
 
     def isUpdatePiece(self, index, mapPiece):
+        _LOGGER.debug("isUpdatePiece " + str(index) + ' ' + str(mapPiece))
+
         value = str(index) + '-' + str(mapPiece)
         
         if self.mapPieces[index] != value:
@@ -19,20 +24,27 @@ class Map:
 
             self.isMapUpdated = False
 
+            _LOGGER.debug("AddMapPiece to update")
             if str(mapPiece) != '1295764014':
                 return True
             else:
                 return False
 
+        _LOGGER.debug("AddMapPiece not to update")
+
     def AddMapPiece(self, mapPiece, b64):
+        _LOGGER.debug("AddMapPiece " + str(mapPiece) + ' ' + str(b64))
+
         decoded = self.decompress7zBase64Data(b64)
 
         decoded = list(decoded)
         MATRIX_PIECE = np.reshape(decoded,(100,100))
 
         self.buffer[mapPiece] = MATRIX_PIECE
+        _LOGGER.debug("AddMapPiece done")
 
     def decompress7zBase64Data(self, data):
+        _LOGGER.debug("decompress7zBase64Data begin")
         finalArray = bytearray()
 
         # Decode Base64
@@ -47,10 +59,14 @@ class Map:
 
         dec = lzma.LZMADecompressor(lzma.FORMAT_AUTO, None, None)
 
-        return dec.decompress(finalArray)
+        decompressed_data = dec.decompress(finalArray)
+
+        _LOGGER.debug("decompress7zBase64Data done")
+        return decompressed_data
     
     def GetBase64Map(self):
         if self.isMapUpdated == False:
+            _LOGGER.debug("GetBase64Map begin")
             im = Image.new("RGBA", (6400, 6400))
             draw = ImageDraw.Draw(im)
 
@@ -95,4 +111,5 @@ class Map:
 
             base64Image = base64.b64encode(buffered.getvalue())
 
+            _LOGGER.debug("GetBase64Map done")
         return base64Image
\ No newline at end of file
